import { Users } from './mongodb';
import type User from '../types/User';
import type Resources from '../types/Resources';

export const getAllUsers = async () => {
    const users = await Users();
    return users.find({}).toArray() as Promise<User[]>;
}

export const createUser = async (user: User) => {
    const newUser = await (await Users()).insertOne(user);
    return newUser;
}

export const getUserByNickOrEmail = async (searchString: string) => {
    const users = await Users();
    return users.findOne({
        $or: [
            { username: searchString },
            { email: searchString }
        ]
    }) as Promise<User | null>;
}

export const getUserResources = async (username: string): Promise<Resources> => {
    const users = await Users();
    const user = await users.findOne({ username });

    const defaultResources: Resources = {
        coal: 0,
        iron: 0,
        gold: 0
    };

    return user?.resources === undefined ? defaultResources : user?.resources;
}

export const updateUserResources = async (username: string, resources: any) => {
    const users = await Users();
    await users.updateOne({ username }, {
        $set: {
            resources
        }
    });
}